==> gambit-0.2005.06.13.tar.gz: gambit-0.2005.06.13/sources/tools/enumpoly/gpoly.cc <==
//
// $Source: /cvsroot/gambit/gambit/sources/tools/enumpoly/Attic/gpoly.cc,v $
// $Date: 2005/06/13 02:32:35 $
// $Revision: 1.1.2.3 $
//
// DESCRIPTION:
// Instantiation of common gPoly classes
//
// This file is part of Gambit
// Copyright (c) 2002, The Gambit Project
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//

#include "gpoly.imp"
#include "double.h"
#include "math/rational.h"
#include "math/gnumber.h"

#ifdef UNUSED
double gPoly<double>::String_Coeff(double nega)
{
  double doub;
  gText Coeff = "";
  while (charc >= '0' && charc <= '9' || charc == '.'){
    Coeff += charc;
    charnum++;
    GetChar();
  }
  if (Coeff == "") return (nega);
  else return (nega * FromText(Coeff,doub));  
}
#endif  // UNUSED

template<> gDouble gPoly<gDouble>::String_Coeff(gDouble nega)
{
  double doub;
  std::string Coeff = "";
  while (charc >= '0' && charc <= '9' || charc == '.'){
    Coeff += charc;
    charnum++;
    GetChar();
  }
  if (Coeff == "") return (nega);
  else return (nega * (gDouble)FromText(Coeff,doub));  
}

template<> gRational gPoly<gRational>::String_Coeff(gRational nega)
{
  gRational rat;
  std::string Coeff = "";
  while (charc >= '0' && charc <= '9' || charc == '/' || charc == '.'){
    Coeff += charc;
    charnum++;
    GetChar();
  }
  if (Coeff == "") return (nega);
  else return (nega * ToRational(Coeff));
}

template<> gNumber gPoly<gNumber>::String_Coeff(gNumber nega)
{
  gNumber num;
  std::string Coeff = "";
  while (charc >= '0' && charc <= '9' || charc == '/' || charc == '.'){
    Coeff += charc;
    charnum++;
    GetChar();
  }

  if (Coeff == "") return (nega);
  else return (nega * gNumber(FromText(Coeff, num)));  
}

template class gPoly<gRational>;
template gPoly<gRational> operator*(const gRational val, const gPoly<gRational> &poly);
template gPoly<gRational> operator*(const gPoly<gRational> &poly, const gRational val);

template gPoly<gDouble> TogDouble(const gPoly<gRational>&);
template gPoly<gDouble> NormalizationOfPoly(const gPoly<gRational>&);

template std::string &operator<<(std::string &, const gPoly<gRational> &);

template class gPoly<gNumber>;
template gPoly<gNumber> operator*(const gNumber val, const gPoly<gNumber> &poly);
template gPoly<gNumber> operator*(const gPoly<gNumber> &poly, const gNumber val);

template gPoly<gDouble> TogDouble(const gPoly<gNumber>&);
template gPoly<gDouble> NormalizationOfPoly(const gPoly<gNumber>&);

template std::string &operator<<(std::string &, const gPoly<gNumber> &);

template class gPoly<gDouble>;
template gPoly<gDouble> operator*(const gDouble val, const gPoly<gDouble> &poly);
template gPoly<gDouble> operator*(const gPoly<gDouble> &poly, const gDouble val);
template gPoly<gDouble> operator+(const gDouble val, const gPoly<gDouble> &poly);
template gPoly<gDouble> operator+(const gPoly<gDouble> &poly, const gDouble val);

template gPoly<gDouble> TogDouble(const gPoly<gDouble>&);
template gPoly<gDouble> NormalizationOfPoly(const gPoly<gDouble>&);
template std::string &operator<<(std::string &, const gPoly<gDouble> &);

std::string ToText(const gPoly<gNumber> &p)
{
  std::string t;
  t << p;
  return t;
}

==> gambit-0.2005.12.12.tar.gz: gambit-0.2005.12.12/sources/tools/enumpoly/gpoly.cc <==
//
// $Source: /cvsroot/gambit/gambit/sources/tools/enumpoly/Attic/gpoly.cc,v $
// $Date: 2005/12/06 17:34:46 $
// $Revision: 1.1.2.7 $
//
// DESCRIPTION:
// Instantiation of common gPoly classes
//
// This file is part of Gambit
// Copyright (c) 2002, The Gambit Project
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//

#include "gpoly.imp"
#include "double.h"
#include "libgambit/libgambit.h"

#ifdef UNUSED
double gPoly<double>::String_Coeff(double nega)
{
  double doub;
  gText Coeff = "";
  while (charc >= '0' && charc <= '9' || charc == '.'){
    Coeff += charc;
    charnum++;
    GetChar();
  }
  if (Coeff == "") return (nega);
  else return (nega * FromText(Coeff,doub));  
}
#endif  // UNUSED

template<> gDouble gPoly<gDouble>::String_Coeff(gDouble nega)
{
  double doub;
  std::string Coeff = "";
  while (charc >= '0' && charc <= '9' || charc == '.'){
    Coeff += charc;
    charnum++;
    GetChar();
  }
  if (Coeff == "") return (nega);
  else return (nega * (gDouble) ToDouble(Coeff));
}

template<> gbtRational gPoly<gbtRational>::String_Coeff(gbtRational nega)
{
  gbtRational rat;
  std::string Coeff = "";
  while (charc >= '0' && charc <= '9' || charc == '/' || charc == '.'){
    Coeff += charc;
    charnum++;
    GetChar();
  }
  if (Coeff == "") return (nega);
  else return (nega * ToRational(Coeff));
}

template<> gbtNumber gPoly<gbtNumber>::String_Coeff(gbtNumber nega)
{
  gbtNumber num;
  std::string Coeff = "";
  while (charc >= '0' && charc <= '9' || charc == '/' || charc == '.'){
    Coeff += charc;
    charnum++;
    GetChar();
  }

  if (Coeff == "") return (nega);
  else return (nega * ToNumber(Coeff));
}

template class gPoly<gbtRational>;
template gPoly<gbtRational> operator*(const gbtRational val, const gPoly<gbtRational> &poly);
template gPoly<gbtRational> operator*(const gPoly<gbtRational> &poly, const gbtRational val);

template gPoly<gDouble> TogDouble(const gPoly<gbtRational>&);
template gPoly<gDouble> NormalizationOfPoly(const gPoly<gbtRational>&);

template std::string &operator<<(std::string &, const gPoly<gbtRational> &);

template class gPoly<gbtNumber>;
template gPoly<gbtNumber> operator*(const gbtNumber val, const gPoly<gbtNumber> &poly);
template gPoly<gbtNumber> operator*(const gPoly<gbtNumber> &poly, const gbtNumber val);

template gPoly<gDouble> TogDouble(const gPoly<gbtNumber>&);
template gPoly<gDouble> NormalizationOfPoly(const gPoly<gbtNumber>&);

template std::string &operator<<(std::string &, const gPoly<gbtNumber> &);

template class gPoly<gDouble>;
template gPoly<gDouble> operator*(const gDouble val, const gPoly<gDouble> &poly);
template gPoly<gDouble> operator*(const gPoly<gDouble> &poly, const gDouble val);
template gPoly<gDouble> operator+(const gDouble val, const gPoly<gDouble> &poly);
template gPoly<gDouble> operator+(const gPoly<gDouble> &poly, const gDouble val);

template gPoly<gDouble> TogDouble(const gPoly<gDouble>&);
template gPoly<gDouble> NormalizationOfPoly(const gPoly<gDouble>&);
template std::string &operator<<(std::string &, const gPoly<gDouble> &);

std::string ToText(const gPoly<gbtNumber> &p)
{
  std::string t;
  t << p;
  return t;
}
